@@ -198,39 +198,6 @@ extern int sexdebug;
     REC_SEX_TOK_SHARP = 289
   };
 #endif
-/* Tokens.  */
-#define REC_SEX_TOK_INT 258
-#define REC_SEX_TOK_REAL 259
-#define REC_SEX_TOK_STR 260
-#define REC_SEX_TOK_NAM 261
-#define REC_SEX_TOK_COLON 262
-#define REC_SEX_TOK_QM 263
-#define REC_SEX_TOK_IMPLIES 264
-#define REC_SEX_TOK_AND 265
-#define REC_SEX_TOK_OR 266
-#define REC_SEX_TOK_EQL 267
-#define REC_SEX_TOK_NEQ 268
-#define REC_SEX_TOK_LT 269
-#define REC_SEX_TOK_GT 270
-#define REC_SEX_TOK_LTE 271
-#define REC_SEX_TOK_GTE 272
-#define REC_SEX_TOK_SAMETIME 273
-#define REC_SEX_TOK_AFTER 274
-#define REC_SEX_TOK_BEFORE 275
-#define REC_SEX_TOK_SUB 276
-#define REC_SEX_TOK_ADD 277
-#define REC_SEX_TOK_MUL 278
-#define REC_SEX_TOK_DIV 279
-#define REC_SEX_TOK_MOD 280
-#define REC_SEX_TOK_MAT 281
-#define REC_SEX_TOK_AMP 282
-#define REC_SEX_TOK_NEG 283
-#define REC_SEX_TOK_MIN 284
-#define REC_SEX_TOK_NOT 285
-#define REC_SEX_TOK_BP 286
-#define REC_SEX_TOK_EP 287
-#define REC_SEX_TOK_ERR 288
-#define REC_SEX_TOK_SHARP 289
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
@@ -242,7 +209,7 @@ union YYSTYPE
   rec_sex_ast_node_t node;
   rec_sex_ast_t ast;
 
-#line 246 "rec-sex-tab.c" /* yacc.c:355  */
+#line 213 "rec-sex-tab.c" /* yacc.c:355  */
 };
 
 typedef union YYSTYPE YYSTYPE;
@@ -258,7 +225,7 @@ int sexparse (rec_sex_parser_t sex_parser);
 
 /* Copy the second part of user declarations.  */
 
-#line 262 "rec-sex-tab.c" /* yacc.c:358  */
+#line 229 "rec-sex-tab.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -1401,49 +1368,49 @@ yyreduce:
        rec_sex_ast_set_top (ast, (yyvsp[0].node));
        rec_sex_parser_set_ast (sex_parser, ast);
      }
-#line 1405 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1372 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 3:
 #line 134 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { (yyval.node) = (yyvsp[0].node); }
-#line 1411 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1378 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 4:
 #line 135 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { (yyval.node) = (yyvsp[0].node); }
-#line 1417 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1384 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 5:
 #line 136 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { (yyval.node) = (yyvsp[0].node); }
-#line 1423 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1390 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 6:
 #line 137 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { (yyval.node) = (yyvsp[0].node); }
-#line 1429 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1396 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 7:
 #line 139 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP3 (REC_SEX_OP_COND, (yyval.node), (yyvsp[-4].node), (yyvsp[-2].node), (yyvsp[0].node)); }
-#line 1435 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1402 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 8:
 #line 140 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP2 (REC_SEX_OP_EQL, (yyval.node), (yyvsp[-2].node), (yyvsp[0].node)); }
-#line 1441 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1408 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 9:
 #line 141 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP2 (REC_SEX_OP_NEQ, (yyval.node), (yyvsp[-2].node), (yyvsp[0].node)); }
-#line 1447 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1414 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 10:
@@ -1459,125 +1426,125 @@ yyreduce:
 
       CREATE_NODE_OP2 (REC_SEX_OP_MAT, (yyval.node), (yyvsp[-2].node), (yyvsp[0].node));
     }
-#line 1463 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1430 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 11:
 #line 154 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP2 (REC_SEX_OP_ADD, (yyval.node), (yyvsp[-2].node), (yyvsp[0].node)); }
-#line 1469 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1436 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 12:
 #line 155 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP2 (REC_SEX_OP_SUB, (yyval.node), (yyvsp[-2].node), (yyvsp[0].node)); }
-#line 1475 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1442 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 13:
 #line 156 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP2 (REC_SEX_OP_MUL, (yyval.node), (yyvsp[-2].node), (yyvsp[0].node)); }
-#line 1481 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1448 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 14:
 #line 157 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP2 (REC_SEX_OP_DIV, (yyval.node), (yyvsp[-2].node), (yyvsp[0].node)); }
-#line 1487 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1454 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 15:
 #line 158 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP2 (REC_SEX_OP_MOD, (yyval.node), (yyvsp[-2].node), (yyvsp[0].node)); }
-#line 1493 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1460 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 16:
 #line 159 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP2 (REC_SEX_OP_GT, (yyval.node), (yyvsp[-2].node), (yyvsp[0].node)); }
-#line 1499 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1466 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 17:
 #line 160 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP2 (REC_SEX_OP_LT, (yyval.node), (yyvsp[-2].node), (yyvsp[0].node)); }
-#line 1505 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1472 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 18:
 #line 161 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP2 (REC_SEX_OP_GTE, (yyval.node), (yyvsp[-2].node), (yyvsp[0].node)); }
-#line 1511 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1478 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 19:
 #line 162 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP2 (REC_SEX_OP_LTE, (yyval.node), (yyvsp[-2].node), (yyvsp[0].node)); }
-#line 1517 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1484 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 20:
 #line 163 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP2 (REC_SEX_OP_AFTER, (yyval.node), (yyvsp[-2].node), (yyvsp[0].node)); }
-#line 1523 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1490 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 21:
 #line 164 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP2 (REC_SEX_OP_BEFORE, (yyval.node), (yyvsp[-2].node), (yyvsp[0].node)); }
-#line 1529 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1496 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 22:
 #line 165 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP2 (REC_SEX_OP_SAMETIME, (yyval.node), (yyvsp[-2].node), (yyvsp[0].node)); }
-#line 1535 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1502 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 23:
 #line 166 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP2 (REC_SEX_OP_IMPLIES, (yyval.node), (yyvsp[-2].node), (yyvsp[0].node)); }
-#line 1541 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1508 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 24:
 #line 167 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP1 (REC_SEX_OP_NOT, (yyval.node), (yyvsp[0].node)); }
-#line 1547 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1514 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 25:
 #line 168 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP2 (REC_SEX_OP_AND, (yyval.node), (yyvsp[-2].node), (yyvsp[0].node)); }
-#line 1553 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1520 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 26:
 #line 169 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP2 (REC_SEX_OP_OR, (yyval.node), (yyvsp[-2].node), (yyvsp[0].node)); }
-#line 1559 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1526 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 27:
 #line 170 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP2 (REC_SEX_OP_CONCAT, (yyval.node), (yyvsp[-2].node), (yyvsp[0].node)); }
-#line 1565 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1532 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 28:
 #line 171 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { CREATE_NODE_OP1 (REC_SEX_OP_SHA, (yyval.node), (yyvsp[0].node)); }
-#line 1571 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1538 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
   case 29:
 #line 172 "../../src/rec-sex-tab.y" /* yacc.c:1646  */
     { (yyval.node) = (yyvsp[-1].node); }
-#line 1577 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1544 "rec-sex-tab.c" /* yacc.c:1646  */
     break;
 
 
-#line 1581 "rec-sex-tab.c" /* yacc.c:1646  */
+#line 1548 "rec-sex-tab.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
