@@ -79,39 +79,6 @@ extern int sexdebug;
     REC_SEX_TOK_SHARP = 289
   };
 #endif
-/* Tokens.  */
-#define REC_SEX_TOK_INT 258
-#define REC_SEX_TOK_REAL 259
-#define REC_SEX_TOK_STR 260
-#define REC_SEX_TOK_NAM 261
-#define REC_SEX_TOK_COLON 262
-#define REC_SEX_TOK_QM 263
-#define REC_SEX_TOK_IMPLIES 264
-#define REC_SEX_TOK_AND 265
-#define REC_SEX_TOK_OR 266
-#define REC_SEX_TOK_EQL 267
-#define REC_SEX_TOK_NEQ 268
-#define REC_SEX_TOK_LT 269
-#define REC_SEX_TOK_GT 270
-#define REC_SEX_TOK_LTE 271
-#define REC_SEX_TOK_GTE 272
-#define REC_SEX_TOK_SAMETIME 273
-#define REC_SEX_TOK_AFTER 274
-#define REC_SEX_TOK_BEFORE 275
-#define REC_SEX_TOK_SUB 276
-#define REC_SEX_TOK_ADD 277
-#define REC_SEX_TOK_MUL 278
-#define REC_SEX_TOK_DIV 279
-#define REC_SEX_TOK_MOD 280
-#define REC_SEX_TOK_MAT 281
-#define REC_SEX_TOK_AMP 282
-#define REC_SEX_TOK_NEG 283
-#define REC_SEX_TOK_MIN 284
-#define REC_SEX_TOK_NOT 285
-#define REC_SEX_TOK_BP 286
-#define REC_SEX_TOK_EP 287
-#define REC_SEX_TOK_ERR 288
-#define REC_SEX_TOK_SHARP 289
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
@@ -123,7 +90,7 @@ union YYSTYPE
   rec_sex_ast_node_t node;
   rec_sex_ast_t ast;
 
-#line 127 "rec-sex-tab.h" /* yacc.c:1909  */
+#line 94 "rec-sex-tab.h" /* yacc.c:1909  */
 };
 
 typedef union YYSTYPE YYSTYPE;
