@@ -2,7 +2,7 @@
 #
 # recins.sh - System tests for recins.
 #
-# Copyright (C) 2010, 2011, 2012 Jose E. Marchesi.
+# Copyright (C) 2010-2015 Jose E. Marchesi.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -111,7 +111,7 @@ test_declare_input_file external-descriptor-types \
 ' 
 
 test_declare_input_file external-descriptor \
-'%rec: Patata external-descriptor-types.in
+'%rec: Patata recins-external-descriptor-types.in
 
 foo: 10
 '
@@ -351,7 +351,7 @@ test_tool recins-external-descriptor ok \
           recins \
           '-t Patata -f foo -v 20' \
           external-descriptor \
-'%rec: Patata external-descriptor-types.in
+'%rec: Patata recins-external-descriptor-types.in
 
 foo: 10
 
